Calculates (the estimated value of) the matrix X*beta_est.
calculate_XB_estimated(X, beta_est, g, vars_est, method_estimate_beta, TT)Returns a NxT matrix. If vars_est is set to 0, it returns NA.
X: NxTxp array containing the observable variables
estimated values of beta
Vector with estimated group membership for all individuals
number of variables that will be included in the algorithm and have their coefficient estimated. This is usually equal to the number of observable variables.
defines how beta is estimated. Default case is an estimated beta for each individual. Default value is "individual." Possible values are "homogeneous", "group" or "individual".
length of time series