Calculates Z = Y - X*beta_est - LgFg. It is used in the estimate of the common factorstructure.
calculate_Z_common(
Y,
X,
beta_est,
g,
lgfg_list,
vars_est,
kg,
method_estimate_beta,
method_estimate_factors,
initialise = FALSE
)NxT matrix
Y: NxT dataframe with the panel data of interest
X: NxTxp array containing the observable variables
estimated values of beta
Vector with group membership for all individuals
This is a list (length number of groups) containing FgLg for every group.
number of variables that will be included in the algorithm and have their coefficient estimated. This is usually equal to the number of observable variables.
number of group specific factors to be estimated
defines how beta is estimated. Default case is an estimated beta for each individual. Default value is "individual." Possible values are "homogeneous", "group" or "individual".
defines method of robust estimaton of the factors: "macro", "pertmm" or "cz"
indicator of being in the initialisation phase