Returns a matrix with a row for each candidate value for C.
The first column contains the optimized number of groups (for each candidate C).
The second columns does the same for the number of common factors.
Column 3 until 22 do the same for the number of group specific factors. This is set to NA if the configuration has less than 20 groups estimated.
Arguments
df_results
dataframe with results for each estimated configuration
df_pic
dataframe with the PIC for each configuration and for each candidate C
C_candidates
candidates for C (parameter in PIC)
limit_est_groups
maximum allowed number of groups that can be estimated