Returns list (with as length the number of groups) with lgfg (product of grouploadings and groupfactors). Each element of the list with the assumption that all individuals are in the same group k. This function is used to speed up code.
calculate_lgfg(
lambda_group,
factor_group,
S,
k,
kg,
num_factors_may_vary,
NN,
TT
)list with S elements: each element contains a matrix with NN rows and TT columns with the estimated group factor structure of this particular group
loadings of the estimated group specific factors
estimated group specific factors
number of groups
number of common factors
vector with the number of group specific factors for each group
whether or not the number of groupfactors is constant over all groups or not
number of time series
length of time series