Learn R Programming

RCTS (version 0.2.4)

calculate_obj_for_g: Calculates objective function for individual i and group k in order to estimate group membership.

Description

Helpfunction in update_g(). Depends on an not yet established group k ( cannot use lgfg_list)

Usage

calculate_obj_for_g(i, k, errors_virtual, rho_parameters, robust, TT)

Value

numeric value

Arguments

i

individual

k

group

errors_virtual

list with errors for each possible group

rho_parameters

median and madn of the calculated error term

robust

robust or classical estimation

TT

length of time series