create_covMat_crosssectional_dependence: Function used in generating simulated data with non normal errors.
Description
Used to include cross-sectional dependence or serial dependence into the simulated panel data.
Usage
create_covMat_crosssectional_dependence(parameter, NN)
Value
NxN covariance matrix
Arguments
- parameter
amount of cross-sectional dependence
- NN
number of time series