Learn R Programming

RCTS (version 0.2.4)

define_kg_candidates: Defines the set of combinations of group specific factors.

Description

Defines the set of combinations of group specific factors.

Usage

define_kg_candidates(S, kg_min, kg_max, nfv = TRUE, limit_est_groups = 20)

Value

Returns a data frame where each row contains the number of group specific factors for all the estimated groups. The number of columns is set to 20 (the current maximum amount of group that can be estimated)

Arguments

S

number of estimated groups

kg_min

minimum value for number of group specific factors

kg_max

minimum value for number of group specific factors

nfv

logical; whether the number of group specific factors is allowed to change among the groups

limit_est_groups

maximum allowed number of groups that can be estimated

Examples

Run this code
define_kg_candidates(3, 2, 4)

Run the code above in your browser using DataLab