Function that returns the set of combinations of groupfactors for which the algorithm needs to run.
kg_candidates_expand(S, kg_min, kg_max, limit_est_groups = 20)data.frame where each row contains a possible combination of group specific factors for each of the groups
number of groups
minimum value for number of group specific factors
minimum value for number of group specific factors
maximum allowed number of groups that can be estimated