Learn R Programming

RCTS (version 0.2.4)

restructure_X_to_order_slowN_fastT: Restructures X (which is an 3D-array of dimensions (N,T,p) to a 2D-matrix of dimension (NxT,p).

Description

Restructures X (which is an 3D-array of dimensions (N,T,p) to a 2D-matrix of dimension (NxT,p).

Usage

restructure_X_to_order_slowN_fastT(X, vars_est)

Value

The function returns a 2D-array, unless the input X is NA, in which case the output will be NA as well.

Arguments

X

input

vars_est

number of variables that will be included in the algorithm and have their coefficient estimated. This is usually equal to the number of observable variables.