Helpfunction in create_true_beta() for the option beta_true_heterogeneous_groups. (This is the default option.)
beta_true_heterogroups(
vars,
S_true,
extra_beta_factor = 1,
limit_true_groups = 12
)matrix where the number of rows equals S_true, and the number of columns equals max(1, vars)
number of observable variables
true number of groups: should be at least 1 and maximum limit_true_groups
option to multiply the coefficients in true beta; default = 1
Maximum number of true groups in a simulation-DGP for which the code in this package is implemented. Currently equals 12. For application on realworld data this parameter is not relevant.