Returns a data frame where each row contains the number of group specific factors for all the estimated groups.
The number of columns is set to 20 (the current maximum amount of group that can be estimated)
Arguments
S
number of estimated groups
kg_min
minimum value for number of group specific factors
kg_max
minimum value for number of group specific factors
nfv
logical; whether the number of group specific factors is allowed to change among the groups
limit_est_groups
maximum allowed number of groups that can be estimated